pyxmpp.jid

Package pyxmpp :: Module jid |
[hide private]

# Module jid

source code

jid -- Jabber ID handling

Normative reference:
  - RFC 3920

Classes | [hide private]
| JID JID.

Functions | [hide private]
are_domains_equal(a, b) Compare two International Domain Names. | source code

Variables | [hide private]
| __revision__ = ``'``$Id: jid.py 714 2010-04-05 10:20:10Z jajcus $``'``
| node_invalid_re = `re.compile(r'`(?u)``[`"&\'/:<>@\s\x00`-`\x19`]`')`
| resource_invalid_re = `re.compile(r'`(?u)``[`\s\x00`-`\x19`]`')`
| __package__ = ``'``pyxmpp``'``

Imports: re, weakref, warnings, idna, nodeprep, resourceprep, JIDError

Function Details | [hide private]

### are_domains_equal(a, b) | source code
Compare two International Domain Names. Parameters: `a` - ,`b`: domains names to compare Returns: True `a` and `b` are equal as domain names.